@@ -1,5 +1,5 @@
 package Kephra::Config::Default::GlobalSettings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use strict;
 use warnings;
@@ -28,7 +28,7 @@ sub get {
 					document_list => '&document_change',
 					document_selection => 'textselection_contextmenu',
 					file_history => '&file_history',
-					file_insert_templates => '&insert_templates',
+					insert_templates => '&insert_templates',
 					marker_margin => 'markermargin_contextmenu',
 					status_eol => 'status_lineendchar_contextmenu',
 					status_encoding => 'status_encoding_contextmenu',
@@ -39,7 +39,7 @@ sub get {
 				},
 			},
 			error_output => 'panel',                         # (dialog|console|panel|none)
-			iconset_path => 'interface/icon/set/jenne',                # rootpath for all icons
+			iconset_path => 'interface/icon/set/jenne',      # rootpath for all icons
 			localisation => {
 				directory => 'localisation',
 				file => 'english.conf',                                # file relative to the localisation directory, defines language of the texts in the program
@@ -71,7 +71,7 @@ sub get {
 				},
 			},
 			searchbar => {
-				autofocus => 1,
+				autofocus => 0,
 				autohide => 0,
 				contextmenu => 'toolbar_search',
 				contextmenu_visible => 1,
@@ -114,6 +114,12 @@ sub get {
 				visible => 1,
 			},
 			window => {
+				default => {
+					position_x => 0,
+					position_y => 0,
+					size_x => 800,
+					size_y => 600,
+				},
 				fullscreen => 0,
 				icon => 'interface/icon/app/proton.xpm',
 				max_number => 1,
@@ -149,7 +155,7 @@ sub get {
 				position_y    => 100,
 				position_x    => 100,
 				tooltips      => 1,
-				transparency  => 0.7,  # 1 visible .. 0 unvisible
+				transparency  => 0.3,  # 0 - full visible .. 1 - invisible
 				width         => 436,
 			},
 		},
@@ -251,7 +257,7 @@ sub get {
 			defaultsettings => {
 				new => {                  # defaults for new docs
 					EOL      => 'OS',     # (OS|auto|cr|lf|cr+lf) end of line character, OS means current OS standart -NI auto means take setting of the last touched file
-					codepage => 'ascii',  # (ascii|utf8) codepage, used for charset
+					codepage => '8bit',   # (8bit|utf8) codepage, used for charset
 					cursor_pos => 0,
 					readonly => 'no',     # (0|1|2|on|off|protect) if =1 it set a write protection on readonly files
 					syntaxmode => 'perl', # (auto|none|lang_id) which syntaxstyle on new files
