@@ -110,73 +110,39 @@ sub get {
 				},
 				file => {
 					new => 'New',
-
 					open => 'Open ...',
-
 					'open-dir' => 'Open Dir ...',
-
 					reload => 'Reload',
-
 					'reload-all' => 'Reload All',
-
 					rename => 'Rename ...',
-
 					insert => 'Insert From ...',
-
 					close => {
-
 						current => 'Close',
-
 						all => 'Close All',
-
 						other => 'Close Other',
-
 						unsaved => 'Close Unsaved',
-
 						'all-unsaved' => 'Close All Unsaved',
-
 						'other-unsaved' => 'Close Other Unsaved',
-
 					},
-
 					save => {
-
 						current => 'Save',
-
 						all => 'Save All',
-
 						as => 'Save As ...',
-
 						'copy-as' => 'Save Copy ...',
-
 					},
-
 					print => 'Print ...',
-
 					session => {
-
 						open => 'Open ...',
-
 						add => 'Add ...',
-
 						save => 'Save ...',
-
 						import => 'Import ...',
-
 						export => 'Export ...',
-
 						'backup-open' => 'Restore Backup',
-
 						'backup-save' => 'Save Backup',
-
 						'history-open-all' => 'Open All',
-
 					},
-
 				},
-
 				edit => {
-
 					changes => {
 						undo => 'Undo',
 						redo => 'Redo',
@@ -247,1807 +213,915 @@ sub get {
 							'char-right' => 'Move Right',
 							'line-up' => 'Move Up',
 							'line-down' => 'Move Down',
-
 							'page-up' => 'Move Page Up',
-
 							'page-down' => 'Move Page Down',
-
 						},
-
 					},
-
 					document => {
-
 						convert => {
-
 							indent2spaces => 'Indention 2 Whitespace',
-
 							indent2tabs => 'Indention 2 Tab',
-
 							spaces2tabs => 'Spaces 2 Tabs',
-
 							tabs2spaces => 'Tabs 2 Whitespace',
-
 						},
-
 						format => {
-
 							'del-trailing-whitespace' => 'Delete Trailing',
-
 						},
-
 					},
-
 				},
-
 				select => {
-
 					document => 'Select All',
-
 					'to-block-begin' => '',
-
 					'to-block-end' => '',
-
 				},
-
 				search => {
-
 					'attribute' => {
-
 						'autowrap-switch' => 'Auto Wrap',
-
 						'incremental-switch' => 'Incremental Search',
-
 						'regex-switch' => 'Regular Expression',
-
 						match => {
-
 							'case-switch' => 'Match Case',
-
 							'whole-word-switch' => 'Whole Word only',
-
 							'word-begin-switch' => 'Word Begin',
-
 						},
-
 					},
-
 					range => {
-
 						selection => 'Selection',
-
 						document => 'Document',
-
 						'open-docs' => 'Open Documents'
-
 					},
-
 				},
-
 				find => {
-
 					prev => 'Find Previous',
-
 					next => 'Find Next',
-
 					first => 'Find First',
-
 					last => 'Find Last',
-
 					selection => 'Find Selection',
-
 					'mark-all' => 'Mark all Matches',
-
 				},
-
 				replace => {
-
 					prev => 'Replace Backward',
-
 					'next' => 'Replace Forward',
-
 					all => 'Replace All',
-
 					'with-confirm' => 'Replace With Confirm',
-
 					selection => 'Replace Into Selection',
-
 				},
-
 				goto => {
-
 					'last-edit' => 'Goto Last Edit',
-
 					line => 'Goto Line Number  ...',
-
 				},
-
 				marker => {
-
 					'goto-prev-doc' => 'Previous Marker in Doc',
-
 					'goto-next-doc' => 'Next Marker in Doc',
-
 					'goto-prev-all' => 'Goto Previous Marker',
-
 					'goto-next-all' => 'Goto Next Marker',
-
 					'toggle-here' => 'Toggle Marker Here',
-
 					'delete-doc' => 'Delete Marker in Doc',
-
 					'delete-all' => 'Delete All Marker',
-
 				},
-
 				bookmark => {
-
 					goto => {
-
 						1 => 1,
-
 						2 => 2,
-
 						3 => 3,
-
 						4 => 4,
-
 						5 => 5,
-
 						6 => 6,
-
 						7 => 7,
-
 						8 => 8,
-
 						9 => 9,
-
 						'0' => 'O',
-
 					},
-
 					toggle => {
-
 						1 => 1,
-
 						2 => 2,
-
 						3 => 3,
-
 						4 => 4,
-
 						5 => 5,
-
 						6 => 6,
-
 						7 => 7,
-
 						8 => 8,
-
 						9 => 9,
-
 						'0' => 'O',
-
 					},
-
 					'delete-doc' => 'Delete Doc Bookmarks',
-
 					'delete-all' => 'Delete All Bookmarks',
-
 				},
-
 				tool => {
-
 					note => 'Note',
-
 					'note-selection' => 'Note Selection',
-
 					'interpreter-run-document' => 'Run Script',
-
 					'interpreter-stop-document' => 'Stop Script',
-
 					'output' => {
-
 						'inc' => '@INC',
-
 						'env' => '%ENV',
-
 						'selection-dec' => 'Selection in Dec',
-
 						'selection-hex' => 'Selection in Hex',
-
 					},
-
 					'choose-color' => 'Color Picker',
-
+					perl => {
+						'insert-last-var' => 'Insert Var',
+						'copy-string' => 'Copy String',
+					},
 				},
-
 				document => {
-
 					'auto-indention' => 'Autoindention',
-
 					'brace-indention' => 'Braceindention',
-
 					EOL => {
-
 						auto => 'Align',
-
 						'cr+lf' => 'CR+LF (Windows)',
-
 						cr => 'CR (Macintosh)',
-
 						lf => 'LF (Linux)',
-
 					},
-
 					change => {
-
 						back => 'Switch Back',
-
 						prev => 'Previous Tab',
-
 						'next' => 'Next Tab',
-
 					},
-
 					encoding => {
-
 						'ascii' => 'ASCII',
-
 						'latin1' => 'Latin 1',
-
 						'utf8' => 'UTF-8',
-
 					},
-
 					move => {
-
 						left => 'Move Left',
-
 						right => 'Move Right',
-
 					},
-
 					readonly => {
-
 						'as-attr' => 'As Attribute',
-
 						on => 'Always On',
-
 						off => 'Always Off',
-
 					},
-
 					syntaxmode => {
-
 						auto => 'Autoselect',
-
 						none => 'None',
-
 						ada => 'Ada',
-
 						as => 'Actionscript',
-
 						asm => 'Assembler',
-
 						ave => 'Avennue',
-
 						baan => 'Baan',
-
 						batch => 'Batch',
-
 						c => 'C | C++',
-
 						conf => 'Conf',
-
 						context => 'Context',
-
 						cs => 'C#',
-
 						css => 'CSS',
-
 						diff => 'Diff',
-
 						eiffel => 'Eiffel',
-
 						err => 'Errorlist',
-
 						forth => 'Forth',
-
 						fortran => 'FORTRAN 90',
-
 						html => 'HTML',
-
 						idl => 'IDL',
-
 						java => 'Java',
-
 						js => 'Javascript',
-
 						latex => 'LaTeX',
-
 						lisp => 'LISP',
-
 						lua => 'Lua',
-
 						make => 'Makefile',
-
 						matlab => 'Matlab',
-
 						nsis => 'NSIS',
-
 						pascal => 'Pascal',
-
 						perl => 'Perl',
-
 						php => 'PHP',
-
 						property => 'Property',
-
 						ps => 'Postscript',
-
 						python => 'Python',
-
 						ruby => 'Ruby',
-
 						scheme => 'Scheme',
-
 						sh => 'UNIX Shell',
-
 						sql => 'SQL',
-
 						tcl => 'TCL',
-
 						tex => 'TeX',
-
 						vb => 'Visual Basic',
-
 						vbs => 'VB Script',
-
 						xml => 'XML',
-
 						yaml => 'YAML',
-
 					},
-
 					tabs => {
-
 						hard => 'Tabs (HT = hard tabs)',
-
 						soft => 'Spaces (ST = soft tabs)',
-
 						use => 'Use Tabs',
-
 						width => {
-
 							1 => 1,
-
 							2 => 2,
-
 							3 => 3,
-
 							4 => 4,
-
 							5 => 5,
-
 							6 => 6,
-
 							8 => 8,
-
 						},
-
 					},
-
 				},
-
 				view => {
-
 					dialog => {
-
 						config => 'Config Dialog ...',
-
 						find => 'Search Dialog',
-
 						replace => 'Replace Dialog',
-
 						info => 'About ...',
-
 						keymap => 'Keymap ...',
-
 					},
-
 					documentation => {
-
 						'advanced-tour' => 'Advanced Tour',
-
 						credits => 'Credits',
-
 						'feature-list' => 'Featurelist',
-
 						'navigation-guide' => 'Navigation Guide',
-
 						welcome => 'Welcome',
-
 						'this-version' => 'This Version',
-
 					},
-
 					editpanel => {
-
 						EOL => 'Lineend Marker',
-
 						'caret-line' => 'Caret Line',
-
 						'brace-light' => 'Bracelight',
-
 						'fold-toggle' => {
-
 							all => 'All',
-
 							'here' => 'Here',
-
 							'level' => 'Level',
-
 							'recursively' => 'Recursively',
-
 						},
-
 						font => 'Font',
-
 						'indention-guide' => 'Indention Guide',
-
 						'line-wrap' => 'Line Wrap',
-
 						'right-margin' => 'Right Margin',
-
 						whitespace => 'Whitespace',
-
 						contextmenu => {
-
 							custom => 'Custom',
-
 							default => 'Default',
-
 							no => 'No Menu',
-
 						},
-
 						margin => {
-
 							contexmenu => 'Left Margin',
-
 							marker => 'Marker Margin',
-
 							'line-number' => 'Line Number',
-
 							'text-fold' => 'Fold Margin',
-
 							text => {
-
 								0 => '0 px',
-
 								1 => 1,
-
 								2 => 2,
-
 								3 => 3,
-
 								4 => 4,
-
 								6 => 6,
-
 								8 => 8,
-
 								10 => 10,
-
 								12 => 12,
-
 							},
-
 						},
-
-						
-
 					},
-
 					panel => {
-
 						notepad => 'Notepad',
-
 						output => 'Output',
-
 					},
-
 					menubar => 'Main Menu',
-
 					searchbar => 'Searchbar',
-
 					'searchbar-goto' => 'Searchbar',
-
 					'searchbar-contexmenu' => 'Searchbar',
-
 					statusbar => 'Statusbar',
-
 					'statusbar-contexmenu' => 'Statuscontext',
-
 					'statusbar-info' => {
-
 						date => 'File Date',
-
 						length => 'File Size',
-
 						none => 'Nothing',
-
 					},
-
 					tabbar => 'Tabbar',
-
 					'tabbar-contexmenu' => 'Tabbar',
-
 					toolbar => 'Main Toolbar',
-
 					webpage => {
-
 						documentation => 'Online Docs',
-
 						forum => 'Perl Forum',
-
 					},
-
 					'window-stay-on-top' => 'Stay On Top',
-
 				},
-
 				config => {
-
 					file => {
-
 						global => {
-
 							'open' => 'Open',
-
 							reload => 'Reload',
-
 							'load-from' => 'Load From ...',
-
 							'load-backup' => 'Load Backup',
-
 							'load-defaults' => 'Load Defaults',
-
 							merge => 'Merge With ...',
-
 							save => 'Save',
-
 							'save-as' => 'Save As ...',
-
 						},
-
 						interface => {
-
 							commandlist => 'Command List',
-
 							menubar => 'Main Menu',
-
 							contextmenu => 'Contextmenus',
-
 							maintoolbar => 'Main Toolbar',
-
 							searchbar => 'Searchbar',
-
 							statusbar => 'Statusbar',
-
 							toolbar => 'Toolbar',
-
 						},
-
 						syntaxmode => {
-
 							ada => 'Ada',
-
 							as => 'Actionscript',
-
 							asm => 'Assembler',
-
 							ave => 'Avennue',
-
 							baan => 'Baan',
-
 							batch => 'Batch',
-
 							c => 'C | C++',
-
 							conf => 'Conf',
-
 							context => 'Context',
-
 							cs => 'C#',
-
 							css => 'CSS',
-
 							diff => 'Diff',
-
 							eiffel => 'Eiffel',
-
 							err => 'Errorlist',
-
 							forth => 'Forth',
-
 							fortran => 'FORTRAN 90',
-
 							html => 'HTML',
-
 							idl => 'IDL',
-
 							java => 'Java',
-
 							js => 'Javascript',
-
 							latex => 'LaTeX',
-
 							lisp => 'LISP',
-
 							lua => 'Lua',
-
 							make => 'Makefile',
-
 							matlab =>'Matlab',
-
 							nsis => 'NSIS',
-
 							pascal => 'Pascal',
-
 							perl => 'Perl',
-
 							php => 'PHP',
-
 							property => 'Property',
-
 							ps => 'Postscript',
-
 							python => 'Python',
-
 							ruby => 'Ruby',
-
 							scheme => 'Scheme',
-
 							sh => 'UNIX Shell',
-
 							sql => 'SQL',
-
 							tcl => 'TCL',
-
 							tex => 'TeX',
-
 							vb => 'Visual Basic',
-
 							vbs => 'VB Script',
-
 							xml => 'XML',
-
 							yaml => 'YAML',
-
 						},
-
 						templates => 'Templates',
-
 					},
-
 				},
-
 			},
-
 			help => {
-
 				app => {
-
 					exit => 'shut down the application and save settings and files',
-
 					'exit-unsaved' => 'shut down app without saving the open files',
-
 				},
-
 				file => {
-
 					new => 'opens a new empty text',
-
 					open => 'display an existing textfile as a new document',
-
 					'open-dir' => 'open all files of this directory',
-
 					reload => 'read file from hard drive and replace content with displayed',
-
 					'reload-all' => 'reload all opened files',
-
 					rename => 'change current files name',
-
 					insert => 'insert file content at caret position',
-
 					close => {
-
 						current => 'close current document, if preset the file will be saved',
-
 						all => 'close all open documents',
-
 						other => 'close all open documents but not the current visible',
-
 						unsaved => 'close current document without save it before it',
-
-						'all-unsaved' => 'close all document without save it before it',
-
+					'all-unsaved' => 'close all document without save it before it',
 						'other-unsaved' => 'unsaved closing of all open docs but not the current visible',
-
 					},
-
 					save =>{
-
 						current => 'save the displayed state of the current file',
-
 						all => 'save all the currently opened files',
-
 						as => 'save current document under different file name',
-
 						'copy-as' => 'save doc with different name, keep current version open',
-
 					},
-
 					print => 'print the current document',
-
 					session => {
-
 						open => 'restore an once saved file session',
-
 						add => 'add files of a saved file session',
-
 						save => 'save order and properties of this file session',
-
 						import => 'open files session from another editors format',
-
 						export => 'save files session in another editors format',
-
 						'backup-open' => 'restore the backup session',
-
 						'backup-save' => 'remember current files as the backup session',
-
 						'history-open-all' => 'restore all listed closed files from history',
-
 					},
-
 				},
-
 				edit => {
-
 					changes => {
-
 						undo => 'undo the last change in the current document',
-
 						redo => 'redo the last change made undone',
-
 						'undo-several' => 'go several steps back in edit history',
-
 						'redo-several' => 'go several steps forward in edit history',
-
 						'goto-begin' => 'go back to the state before the first edit',
-
 						'goto-end' => 'go forward to the state after the last edit',
-
 						delete => 'deleting history of all editing changes',
-
 					},
-
 					cut => 'cut selected text and store it in the clipboard',
-
 					copy => 'copy selected text to the clipboard',
-
 					paste => 'insert text from the clipboard',
-
 					replace => 'replace selected text with the clipboard',
-
 					delete => 'delete and forget selected text',
-
 					line => {
-
 						cut => 'cut current line and store it in the clipboard',
-
 						copy => 'copy current line to the clipboard',
-
 						duplicate => 'insert below a copy of the current line',
-
 						replace => 'replace current line with the clipboard',
-
 						delete => 'delete and forget current line',
-
 						'delete-left' => 'delete left side from textcursor of current line',
-
 						'delete-right' => 'delete right side from textcursor of current line',
-
 						move => {
-
 							'line-up' => 'move current line one line up',
-
 							'line-down' => 'move current line one line down',
-
 							'page-up' => 'move current line one page up',
-
 							'page-down' => 'move current line one page down',
-
 						},
-
 					},
-
 					selection => {
-
 						convert => {
-
 							uppercase => 'turn selected text to uppercase',
-
 							lowercase => 'turn selected text to lowercase',
-
 							titlecase => 'turn first char of every word uppercase',
-
 							sentencecase => 'turn first char of every sentence uppercase',
-
 							spaces2tabs => 'convert groups of whitespace to tabs',
-
 							tabs2spaces => 'depends on current tab width',
-
 							spaces2entities => 'convert all whitespace to &npsp;',
-
 							entities2spaces => 'convert &npsp; to whitespace',
-
 							chars2entities => 'convert ISO 8859-1 character to HTML entities',
-
 							entities2chars => 'convert HTML entities to ISO 8859-1 characters',
-
 						},
-
 						comment => {
-
 							'add-perl' => 'insert # after every indention',
-
 							'del-perl' => 'remove all # following the indention',
-
 							'toggle-perl' => 'comment all uncommented lines and vici versa',
-
 							'add-c' => 'surround selection with / * and * /',
-
 							'del-c' => 'remove all / * and * / in the selection',
-
 							'add-xml' => 'surround selection with  <!-- and -->',
-
 							'del-xml' => 'remove all <!-- and --> in the selection',
-
 						},
-
 						format => {
-
 							'align-on-begin' => 'align line indentions on first line',
-
 							'block-on-right-margin' => 'format to textblock, that not cross right margin',
-
 							'block-on-width' => 'format to textblock with chosen width ...',
-
 							'linewrap-on-right-margin' => 'split lines before they reach the right margin',
-
 							'linewrap-on-width' => 'split lines to a chosen width ...',
-
 							'indent-char' => 'increase indention of the selected lines by 1',
-
 							'dedent-char' => 'decrease indention of the selected lines by 1',
-
 							'indent-tab' => 'increase indention by current tab size',
-
 							'dedent-tab' => 'decrease indention by current tab size',
-
 							'del-trailing-whitespace' => 'delete whitespace on line endings',
-
 							'join-lines' => 'delete end of line (EOL) symbols',
-
 						},
-
 						move => {
-
 							'char-left' => 'move selection one character left',
-
 							'char-right' => 'move selection one character right',
-
 							'line-up' => 'move selection one line up',
-
 							'line-down' => 'move selection one line down',
-
 							'page-up' => 'move selection one page up',
-
 							'page-down' => 'move selection one page down',
-
 						},
-
 					},
-
 					document => {
-
 						convert => {
-
 							indent2spaces => 'convert tabs between linestart and first word',
-
 							indent2tabs => 'convert spaces between linestart and first word',
-
 							spaces2tabs => 'convert all spaces to tabs in the current doc',
-
 							tabs2spaces => 'convert all tabs to spaces in the current doc',
-
 						},
-
 						format => {
-
 							'del-trailing-whitespace' => 'delete all trailing whitespace',
-
 						},
-
 					},
-
 				},
-
 				select => {
-
 					document => 'select entire document',
-
 					'to-block-begin' => '',
-
 					'to-block-end' => '',
-
 				},
-
 				search => {
-
 					attribute => {
-
 						'autowrap-switch' => 'Auto Wrap',
-
 						'incremental-switch' => 'Incremental Search',
-
 						'regex-switch' => 'Regular Expression',
-
 						match => {
-
 							'case-switch' => 'Match Case',
-
 							'whole-word-switch' => 'Whole Word only',
-
 							'word-begin-switch' => 'Word Begin',
-
 						},
-
 					},
-
 					range => {
-
 						selection => 'search and replace only within selected text',
-
 						document => 'search and replace in whole current document',
-
 						'open-docs' => 'search and replace in all open documents',
-
 					},
-
 				},
-
 				find => {
-
 					prev => 'find the previous match of the textsearch',
-
 					next => 'find the next match of the textsearch',
-
 					first => 'find first textsearch match in document',
-
 					last => 'find last textsearch match in document',
-
 					selection => 'remember selected text as current search item',
-
 				},
-
 				replace => {
-
 					prev => 'replace selection and find previous match',
-
 					next => 'replace selection and find next match',
-
 					all => 'replace all matches in current search range',
-
 					'with-confirm' => 'confirm or reject to replace every particular match',
-
 					selection => 'remember selected text as current replace item',
-
 				},
-
 				goto => {
-
 					'last-edit' => 'jump to position of last change in this document',
-
 					line => 'jump to line with chosen number',
-
 				},
-
 				marker => {
-
 					'goto-prev-doc' => 'go to the previous marker (upwards) in this document',
-
 					'goto-next-doc' => 'go to the next marker (downwards) in this document',
-
 					'goto-prev-all' => 'go to the previous marker here or in some previous document',
-
 					'goto-next-all' => 'go to the next marker here or in some next document',
-
 					'toggle-here' => 'set a marker in current line or delete if already present',
-
 					'delete-doc' => 'delete marker just in the current document',
-
 					'delete-all' => 'delete marker in all open documents',
-
 				},
-
 				bookmark => {
-
 					goto => {
-
 						1 => 'go to bookmark number 1',
-
 						2 => 'go to bookmark number 2',
-
 						3 => 'go to bookmark number 3',
-
 						4 => 'go to bookmark number 4',
-
 						5 => 'go to bookmark number 5',
-
 						6 => 'go to bookmark number 6',
-
 						7 => 'go to bookmark number 7',
-
 						8 => 'go to bookmark number 8',
-
 						9 => 'go to bookmark number 9',
-
 						0 => 'go to bookmark number 0',
-
 					},
-
 					toggle => {
-
 						1 => 'set here or remove (if present) bookmark 1',
-
 						2 => 'set here or remove (if present) bookmark 2',
-
 						3 => 'set here or remove (if present) bookmark 3',
-
 						4 => 'set here or remove (if present) bookmark 4',
-
 						5 => 'set here or remove (if present) bookmark 5',
-
 						6 => 'set here or remove (if present) bookmark 6',
-
 						7 => 'set here or remove (if present) bookmark 7',
-
 						8 => 'set here or remove (if present) bookmark 8',
-
 						9 => 'set here or remove (if present) bookmark 9',
-
 						0 => 'set here or remove (if present) bookmark 0',
-
 					},
-
 					'delete-doc' => 'delete bookmarks in the current document',
-
 					'delete-all' => 'delete bookmarks in all documents',
-
 				},
-
 				tool => {
-
 					note => 'jump to the notepad',
-
 					'note-selection' => 'paste selected text on the end of the notepad',
-
 					'interpreter-run-document' => 'run current programm and show result in output panel',
-
 					'interpreter-stop-document' => 'stop the current running output panel process',
-
 					'output' => {
-
 						'inc' => 'display the include paths of the Perl Interpreter in the ouput panel',
-
 						'env' => 'display the environment variables in the ouput panel',
-
 						'selection-dec' => 'display selected text in decimal coding in the ouput panel',
-
 						'selection-hex' => 'display selected text in hexadecimal coding in the ouput panel',
-
 					},
-
 					'choose-color' => 'display text selection as color and choose a new from a rainbow',
-
+					perl => {
+						'insert-last-var' => 'insert last Perl variable that began a line',
+						'copy-string' => 'copy surrounding single or double quoted string',
+					},
 				},
-
 				document => {
-
 					'auto-indention' => 'indents new line like previous when Enter pressed',
-
 					'brace-indention' => 'obey right indention after curly braces when press enter',
-
 					EOL => {
-
 						auto => 'make all line endings like in first line',
-
 						'cr+lf' => 'line endings for Windows or Dos',
-
 						cr => 'convert line endings to the Mac standart',
-
 						lf => 'convert line endings to the UNIX standart',
-
 					},
-
 					change => {
-
 						back => 'switches to the last used document',
-
 						prev => 'changes the current document one tab to the left',
-
 						next => 'changes the current document one tab to the right',
-
 					},
-
 					encoding => {
-
 						'ascii' => 'converts document encoding into ASCII 8 Bit',
-
 						'latin1' => 'converts document encoding into iso-8859-1',
-
 						'utf8' => 'converts document encoding into UTF-8',
-
 					},
-
 					move => {
-
 						left => 'move current document in the tabbar one pos to the left',
-
 						right => 'move current document in the tabbar one pos to the right',
-
 					},
-
 					readonly => {
-
 						'as-attr' => 'turns write protection on if file is readonly',
-
 						on => 'disables every modification of this document',
-
 						off => 'makes document always editable even if it can\'t be saved',
-
 					},
-
 					syntaxmode => {
-
 						auto => 'select syntaxmode depending on fileending',
-
 						none => 'turn any syntaxmode settings off',
-
 						ada => 'activate language settings for Ada',
-
 						as => 'activate settings for Macromedia Actionscript',
-
 						asm => 'language settings for Assembler',
-
 						ave => 'open settings for the Avennue language',
-
 						baan => 'language of the Baan ERP systems',
-
 						batch => 'Microsofts classic commandline batch control language',
-
 						c => 'settings for the C / C++ language family',
-
 						conf => 'for Apache Conf styled configuration files',
-
 						context => 'settings for the ConTeXt Tex Macros',
-
 						cs => 'syntaxmode for Microsoft C-Sharp',
-
 						css => 'syntaxmode for Cascading Style Sheet language',
-
 						diff => 'syntaxmode for patch files',
-
 						eiffel => 'Bertrand Meyers objectoriented language Eiffel',
-
 						err => 'syntaxmode for errorcode files',
-
 						forth => 'language of the Forth systems',
-
 						fortran => 'syntaxmode of the FORmula TRANslation language',
-
 						html => 'syntaxmode for the HyperText Markup Language',
-
 						idl => 'syntaxmode of the Interface Definition Language',
-
 						java => 'Settings for Sun\'s Java language',
-
 						js => 'syntaxmode for Javascript',
-
 						latex => 'syntaxmode for the LaTeX Tex macros',
-
 						lisp => 'LISt Prozessor settings',
-
 						lua => 'syntaxmode for the embedding language Lua',
-
 						make => 'highlighting for make tool scripts',
-
 						matlab => 'MATLAB scripting language',
-
 						nsis => 'language of the Nullsoft Scriptable Install System',
-
 						pascal => 'Niklaus Wirth\'s structured language Pascal',
-
 						perl => 'syntaxmode for Larry Walls Perl',
-
 						php => 'Rasmus Lehrdorf PHP Hypertext Prozessors',
-
 						property => 'Highlighting for simple config files',
-
 						ps => 'Adobe\'s document desciption language Postscript',
-
 						python => 'Guido van Rossums dynamic language Python',
-
 						ruby => 'Yukihiro "Matz" Matsumoto\'s full objectoriented language',
-
 						scheme => 'syntaxmode of the MIT LISP dialect',
-
 						sh => 'settings for the UNIX Bourne Shell',
-
 						sql => 'Structured Query Language originated from IBM',
-
 						tcl => 'Tool Command Language from John Ousterhout',
-
 						tex => 'Donald E. Knuth macro language for type setting',
-
 						vb => 'settings for Microsoft Visual Basic',
-
 						vbs => 'settings for Microsoft Visual Basic Script',
-
 						xml => 'syntaxmode for the eXtensible Markup Language',
-
 						yaml => 'syntaxmode for Indy\'s YAML Ain\'t Markup Language',
-
 					},
-
 					tabs => {
-
 						hard => 'insert a tab while hitting the tab key',
-
 						soft => 'insert several whitespaces while hitting tab key',
-
 						use => 'use tabs (hard tabs) or whitespaces (soft tabs)',
-
 						width => {
-
 							1 => 'set width of tabs to an equal of 1 character',
-
 							2 => 'set width of tabs to an equal of 2 characters',
-
 							3 => 'set width of tabs to an equal of 3 characters',
-
 							4 => 'set width of tabs to an equal of 4 characters',
-
 							5 => 'set width of tabs to an equal of 5 characters',
-
 							6 => 'set width of tabs to an equal of 6 characters',
-
 							8 => 'set width of tabs to an equal of 8 characters',
-
 						},
-
 					},
-
 				},
-
 				view => {
-
 					dialog => {
-
 						config => 'display and change the configuration of the program',
-
 						find => 'open dialog for text search and settings',
-
 						replace => 'open dialog for find and replace text',
-
 						info => 'version numbers, authors, credits, license',
-
 						keymap => 'lists which key kombination triggers which function',
-
 					},
-
 					documentation => {
-
 						'advanced-tour' => 'introduction of unusual but practical features',
-
 						credits => 'list of all involved people',
-
 						'feature-list' => 'thematically sorted description of all functionalities',
-
 						'navigation-guide' => 'explanations of the user interface',
-
 						welcome => 'first steps: how to get help and give feedback',
-
 						'this-version' => 'new features and important changes of the current version',
-
 					},
-
 					editpanel => {
-
 						EOL => 'switch visibility of the end of line marker',
-
 						'caret-line' => 'highlights row where caret(textcursor) is located',
-
 						'brace-light' => 'highlights associated pairs of braices',
-
 						'fold-toggle' => {
-
 							all => 'fold or unfold all visible and not visible nodes',
-
 							here => 'fold or unfold only the node on selected position',
-
 							level => 'fold or unfold all nodes with same depth in hierarchy (amount of parents)',
-
 							recursively => 'fold or unfold this and all nodes below in hierarchy',
-
 						},
-
 						font => 'change font family, size, style etc.',
-
 						'indention-guide' => 'vertical dotted lines in intervals of tab width',
-
 						'line-wrap' => 'breaks long lines on window edge only visually',
-
 						'right-margin' => 'shows straight vertical line on seleted width',
-
 						whitespace => 'set whitespaces and tabs visible as dots and arrows',
-
 						contextmenu => {
-
 							custom => 'aktivate customizable editpanel context menu',
-
 							default => 'aktivate default scintilla context menu',
-
 							no => 'deaktivate all editpanel context menu',
-
 						},
-
 						margin => {
-
 							contexmenu => 'enable or disable the context menu over the margin, left of the edit panel',
-
 							marker => 'margin for bookmarks, marker, debug steps ...',
-
 							'line-number' => 'sets line numbers visible',
-
 							text => {
-
 								0 => 'set extra margin on both sides of textfield to 0 pixel',
-
 								1 => 'set extra margin on both sides of textfield to 1 pixel',
-
 								2 => 'set extra margin on both sides of textfield to 2 pixel',
-
 								3 => 'set extra margin on both sides of textfield to 3 pixel',
-
 								4 => 'set extra margin on both sides of textfield to 4 pixel',
-
 								6 => 'set extra margin on both sides of textfield to 6 pixel',
-
 								8 => 'set extra margin on both sides of textfield to 8 pixel',
-
 								10 => 'set extra margin on both sides of textfield to 10 pixel',
-
 								12 => 'set extra margin on both sides of textfield to 12 pixel',
-
 							},
-
 							'text-fold' => 'switch Margin for the text folding icons',
-
 						},
-
 						maximize => 'toggle all panels and bars to enlarge the edit area',
-
 					},
-
 					panel => {
-
 						notepad => 'switch visibility of the Notepad panel',
-
 						output => 'switch visibility of the Output panel',
-
 					},
-
 					menubar => 'turn main menu on (visible) or off',
-
 					searchbar => 'toolbar with text seach and navigation functions',
-
 					'searchbar-goto' => 'goto searchbar and use find function',
-
 					'searchbar-contexmenu' => 'enable or disable the context menu over the searchbar',
-
 					statusbar => 'switch visibility of the statusbar on bottom of the window',
-
 					'statusbar-contexmenu' => 'enable or disable context menus on statusbar',
-
 					'statusbar-info' => {
-
 						date => 'display change date of the current file in statusbar info field',
-
 						length => 'display size info of the current file in statusbar info field',
-
 						none => 'display nothing in statusbar info field',
-
 					},
-
 					tabbar => 'switch visibility of the tabbar, toolbar for doc selection',
-
 					'tabbar-contexmenu' => 'enable or disable context menus on tabbar',
-
 					toolbar => 'switch visibility of the main toolbar',
-
 					webpage => {
-
 						documentation => 'open online documentation with your default browser',
-
 						forum => 'go to a perl web forum based on current language setting',
-
 					},
-
 					window => {
-
 						fullscreen => 'use maximum screen space',
-
 						'stay-on-top' => 'application window cant be overlapped by other windows',
-
 						'transparent' => 'make main window translucent',
-
 					},
-
 				},
-
 				config => {
-
 					'app-lang' => 'change user interface language to',
-
 					file => {
-
 						global => {
-
 							open => 'open file with current global configurations',
-
 							reload => 'reload current global configuration file',
-
 							'load-from' => 'load global configs from chosen file',
-
 							'load-backup' => 'load global configs from backup',
-
 							'load-defaults' => 'load default global configs',
-
 							merge => 'merge current global configs with settings in this file',
-
 							save => 'save current global configs into the file we load from',
-
 							'save-as' => 'save current global configs into this file',
-
 						},
-
 						interface => {
-
 							commandlist => 'definition for function calls, key binding, icons',
-
 							menubar => 'open definition file for the menubar',
-
 							contextmenu => 'open definition file for all contextmenu',
-
 							maintoolbar => 'open definition file for the main toolbar',
-
 							searchbar => 'open definition file for the searchbar',
-
 							statusbar => 'open definition file for the statusbar',
-
 							toolbar => 'open default definition file for toolbars',
-
 						},
-
 						localisation => 'open translation file for language',
-
 						syntaxmode => {
-
 							ada => 'open file with settings for the Ada language',
-
 							as => 'open file with Macromedia Actionscript settings',
-
 							asm => 'open file with language settings for Assembler',
-
 							ave => 'open settings for the Avennue language',
-
 							baan => 'language of the Baan ERP systems',
-
 							batch => 'Microsofts classic commandline batch control language',
-
 							c => 'open file with settings for the C / C++  languages',
-
 							conf => 'settings for files in the Apache Conf style',
-
 							context => 'settings for ConTeXt Tex Macros',
-
 							cs => 'open file with syntaxmode for Microsoft C-Sharp',
-
 							css => 'settings for the Cascading Style Sheet language',
-
 							diff => 'syntaxmode for patch files',
-
 							eiffel => 'Bertrand Meyers objectoriented language Eiffel',
-
 							err => 'syntaxmode for errorcode files',
-
 							forth => 'settings for the language of the Forth systems',
-
 							fortran => 'syntaxmode von FORmula TRANslation open',
-
 							html => 'syntaxmode for HyperText Markup Language open',
-
 							idl => 'syntaxmode der Interface Definition Language open',
-
 							java => 'open settings for Sun\'s Java language',
-
 							js => 'open syntaxmode for Javascript',
-
 							latex => 'open syntaxmode for the Tex macros named LaTeX',
-
 							lisp => 'open settings for the almighty LISt Prozessor',
-
 							lua => 'settings for the extension language Lua',
-
 							nsis => 'language of the Nullsoft Scriptable Install System',
-
 							make => 'highlighting for make tool scripts',
-
 							matlab => 'MATLAB scripting language',
-
 							pascal => 'settings for Niklaus Wirth\'s procedural language Pascal',
-
 							perl => 'file with syntaxmode for Larry Walls Perl',
-
 							php => 'Rasmus Lehrdorf PHP Hypertext Prozessor',
-
 							property => 'Highlighting for simple config files',
-
 							ps => 'Adobe document description language Postscript',
-
 							python => 'Guido van Rossums dynamic language Python',
-
 							ruby => 'Yukihiro "Matz" Matsumoto\'s full object oriented Ruby',
-
 							scheme => 'open syntaxmode of the MIT LISP dialect Scheme',
-
 							sh => 'open settings for the UNIX Bourne Shell',
-
 							sql => 'Structured Query Language, originated from IBM',
-
 							tcl => 'Tool Command Language from John Ousterhout',
-
 							tex => 'Donald E. Knuth\'s macro language for typesetting',
-
 							vb => 'open file with settings for Microsoft Visual Basic',
-
 							vbs => 'open file with settings for Microsoft Visual Basic Script',
-
 							xml => 'open settings for die eXtensible Markup Language',
-
 							yaml => 'open settings for Indy\'s YAML Ain\'t Markup Language',
-
 						},
-
 						templates => 'open file with the current template definitions',
-
 					},
-
 				},
-
 			},
-
 		},
-
 		dialog => {
-
 			config => {
-
 				title => 'Configuration Dialog',
-
 				panel => {
-
 					general => 'General',
-
 					main_window => 'Main Window',
-
 					edit => 'Edit Panel',
-
 					files => 'Files',
-
 				},
-
 			},
-
 			config_file => {
-
 				load => 'load overall configuration from the file :',
-
 				save => 'store current program configuration into the file :',
-
 			},
-
 			edit => {
-
 				goto_line_headline => 'goto line',
-
 				goto_line_input => 'choose linenumber :',
-
 				wrap_custom_headline => 'custom word wrapping',
-
 				wrap_width_input => 'choose new line width (maximum number of chars) :',
-
 			},
-
 			error => {
-
 				general => 'Error',
-
 				no_param => 'called without needed parameters',
-
 				file => 'file handling error',
-
 				file_find => "can't find file :",
-
 				file_read => "can't read file :",
-
 				file_write => "can't write file :",
-
 				config_read => "can't read config file :",
-
 				config_parse => 'file has no data :',
-
 				write_protected => 'This file is write protected by the file system.',
-
 				write_protected2 => 'Please unlock this or save this text under an other filename.',
-
 			},
-
 			file => {
-
 				files => 'Files',
-
 				open => 'Open File',
-
 				insert => 'Insert File',
-
 				rename => 'Rename File',
-
 				save_as => 'Save File As',
-
 				save_all => 'Save All',
-
 				save_none => 'Save None',
-
 				save_copy_as => 'Save A Copy Of This File As',
-
 				overwrite => 'Overwrite Existing File !',
-
 				close_unsaved => 'Closing Unsafed File',
-
 				save_current => 'Save Current File ?',
-
 				save_open => 'Save All Open Files ?',
-
 				quit_unsaved => 'Closing Unsafed Files :',
-
 				open_session => 'Open File Session',
-
 				add_session => 'Add File Session',
-
 				save_session => 'Save Current File Session',
-
 				import_session => 'Import File Session',
-
 				export_session => 'Export File Session',
-
 				open_dir => 'Open Files of Directory :',
-
 				file_changed => 'File Changed',
-
 				file_changed_msg => 'The following file has changed :',
-
 				file_deleted => 'File Deleted',
-
 				file_deleted_msg => 'The following file can not be found anymore :',
-
 			},
-
 			general => {
-
 				all => 'All',
-
 				apply => 'Apply',
-
 				cancel => 'Cancel',
-
 				changed => 'Changed',
-
 				close => 'Close',
-
 				deleted => 'Deleted',
-
 				dont_allow => 'Your settings dont allow this.',
-
 				ignore => 'Ignore',
-
 				none => 'None',
-
 				overwrite => 'Overwrite',
-
 				reload => 'Reload',
-
 				restore => 'Restore',
-
 				select => 'Select',
-
 				save => 'Save',
-
 				save_reload => 'Save as ... and Reload',
-
 				select => 'Select',
-
 				selected => 'Selected',
-
 			},
-
 			help => {},
-
 			info => {
-
 				title => 'Info about',
-
 				mady_by => 'by',
-
 				licensed => 'licensed under',
-
 				detail => 'see under help > license for credits and',
 				more => 'explicit licenses',
 				homepage => 'for more info visit',
 				contains => 'this version contains',
 				and => 'and',
-
 				wrappes => 'which wrappes',
-
 				extra => 'extra Perl Modules',
-
 				motto => 'Neter of software creation',
-
 				dedication => 'Deditcated to all people who ever tried to write an editor.',
-
 			},
-
 			keyboard_map => {
-
 				title => 'Keyboard Map',
-
 			},
-
 			search => {
-
 				title => 'Find and Replace',
-
 				confirm => {
-
 					title => 'Replace With Confirmation',
-
 					text => 'Replace This ?',
-
 				},
 				label => {
 					search_for => 'Search for :',
